@@ -228,10 +228,10 @@ module ActionController
 
       private
         def normalize!(path)
-          ext = URI.parser.escape(extension.to_s) if extension
+          ext = URI::DEFAULT_PARSER.escape(extension.to_s) if extension
           path << "index" if path[-1] == ?/
-          path << ".#{ext}" if extension && !path.split("?", 2).first.ends_with?(".#{ext}")
-          URI.parser.unescape(path)
+          path << ".#{ext}" if extension && !path.split("?", 2).first.end_with?(".#{ext}")
+          URI::DEFAULT_PARSER.unescape(path)
         end
       end
     end
